@@ -71,7 +71,7 @@ public class AsyncClientHttpExchangeStreaming {
         }
 
         @Override
-        protected void onCharReceived(final CharBuffer buf, final IOControl ioctrl) throws IOException {
+        protected void onCharReceived(final CharBuffer buf, final IOControl ioControl) throws IOException {
             while (buf.hasRemaining()) {
                 System.out.print(buf.get());
             }
