@@ -105,7 +105,7 @@ class DefaultAsyncRequestDirector<T> implements HttpAsyncRequestExecutionHandler
     private final HttpContext localContext;
     private final ResultCallback<T> resultCallback;
     private final ClientAsyncConnectionManager connmgr;
-    private final HttpProcessor httppocessor;
+    private final HttpProcessor httpPocessor;
     private final HttpRoutePlanner routePlanner;
     private final HttpRouteDirector routeDirector;
     private final ConnectionReuseStrategy reuseStrategy;
@@ -145,7 +145,7 @@ class DefaultAsyncRequestDirector<T> implements HttpAsyncRequestExecutionHandler
             final HttpContext localContext,
             final ResultCallback<T> callback,
             final ClientAsyncConnectionManager connmgr,
-            final HttpProcessor httppocessor,
+            final HttpProcessor httpPocessor,
             final HttpRoutePlanner routePlanner,
             final ConnectionReuseStrategy reuseStrategy,
             final ConnectionKeepAliveStrategy keepaliveStrategy,
@@ -161,7 +161,7 @@ class DefaultAsyncRequestDirector<T> implements HttpAsyncRequestExecutionHandler
         this.localContext = localContext;
         this.resultCallback = callback;
         this.connmgr = connmgr;
-        this.httppocessor = httppocessor;
+        this.httpPocessor = httpPocessor;
         this.routePlanner = routePlanner;
         this.reuseStrategy = reuseStrategy;
         this.keepaliveStrategy = keepaliveStrategy;
@@ -328,12 +328,12 @@ class DefaultAsyncRequestDirector<T> implements HttpAsyncRequestExecutionHandler
 
     @Override
     public synchronized void produceContent(
-            final ContentEncoder encoder, final IOControl ioctrl) throws IOException {
+            final ContentEncoder encoder, final IOControl ioControl) throws IOException {
         if (this.log.isDebugEnabled()) {
             this.log.debug("[exchange: " + this.id + "] produce content");
         }
         this.requestContentProduced = true;
-        this.requestProducer.produceContent(encoder, ioctrl);
+        this.requestProducer.produceContent(encoder, ioControl);
         if (encoder.isCompleted()) {
             this.requestProducer.resetRequest();
         }
@@ -404,12 +404,12 @@ class DefaultAsyncRequestDirector<T> implements HttpAsyncRequestExecutionHandler
 
     @Override
     public synchronized void consumeContent(
-            final ContentDecoder decoder, final IOControl ioctrl) throws IOException {
+            final ContentDecoder decoder, final IOControl ioControl) throws IOException {
         if (this.log.isDebugEnabled()) {
             this.log.debug("[exchange: " + this.id + "] Consume content");
         }
         if (this.finalResponse != null) {
-            this.responseConsumer.consumeContent(decoder, ioctrl);
+            this.responseConsumer.consumeContent(decoder, ioControl);
         } else {
             if (this.tmpbuf == null) {
                 this.tmpbuf = ByteBuffer.allocate(2048);
@@ -687,11 +687,9 @@ class DefaultAsyncRequestDirector<T> implements HttpAsyncRequestExecutionHandler
     }
 
     private RequestWrapper wrapRequest(final HttpRequest request) throws ProtocolException {
-        if (request instanceof HttpEntityEnclosingRequest) {
-            return new EntityEnclosingRequestWrapper((HttpEntityEnclosingRequest) request);
-        } else {
-            return new RequestWrapper(request);
-        }
+        return request instanceof HttpEntityEnclosingRequest
+                        ? new EntityEnclosingRequestWrapper((HttpEntityEnclosingRequest) request)
+                        : new RequestWrapper(request);
     }
 
     protected void rewriteRequestURI(
@@ -772,7 +770,7 @@ class DefaultAsyncRequestDirector<T> implements HttpAsyncRequestExecutionHandler
         return null;
     }
 
-    private RoutedRequest handleConnectResponse() throws HttpException {
+    private RoutedRequest handleConnectResponse() {
         RoutedRequest followup = null;
         if (HttpClientParams.isAuthenticating(this.params)) {
             final CredentialsProvider credsProvider = (CredentialsProvider) this.localContext.getAttribute(
@@ -841,7 +839,7 @@ class DefaultAsyncRequestDirector<T> implements HttpAsyncRequestExecutionHandler
     }
 
     private RoutedRequest handleTargetChallenge(
-            final CredentialsProvider credsProvider) throws HttpException {
+            final CredentialsProvider credsProvider) {
         final HttpRoute route = this.mainRequest.getRoute();
         HttpHost target = (HttpHost) this.localContext.getAttribute(
                 ExecutionContext.HTTP_TARGET_HOST);
@@ -854,15 +852,14 @@ class DefaultAsyncRequestDirector<T> implements HttpAsyncRequestExecutionHandler
                     this.targetAuthStrategy, this.targetAuthState, this.localContext)) {
                 // Re-try the same request via the same route
                 return this.mainRequest;
-            } else {
-                return null;
             }
+            return null;
         }
         return null;
     }
 
     private RoutedRequest handleProxyChallenge(
-            final CredentialsProvider credsProvider) throws HttpException {
+            final CredentialsProvider credsProvider) {
         final HttpRoute route = this.mainRequest.getRoute();
         final HttpHost proxy = route.getProxyHost();
         if (this.authenticator.isAuthenticationRequested(proxy, this.currentResponse,
@@ -871,9 +868,8 @@ class DefaultAsyncRequestDirector<T> implements HttpAsyncRequestExecutionHandler
                     this.proxyAuthStrategy, this.proxyAuthState, this.localContext)) {
                 // Re-try the same request via the same route
                 return this.mainRequest;
-            } else {
-                return null;
             }
+            return null;
         }
         return null;
     }
@@ -885,7 +881,7 @@ class DefaultAsyncRequestDirector<T> implements HttpAsyncRequestExecutionHandler
 
     @Override
     public HttpProcessor getHttpProcessor() {
-        return this.httppocessor;
+        return this.httpPocessor;
     }
 
     @Override
