@@ -120,6 +120,7 @@ class MinimalClientExchangeHandlerImpl<T> extends AbstractClientExchangeHandler
         return cancelled;
     }
 
+    @Override
     public void start() throws HttpException, IOException {
         final HttpHost target = this.requestProducer.getTarget();
         final HttpRequest original = this.requestProducer.generateRequest();
@@ -143,8 +144,8 @@ class MinimalClientExchangeHandlerImpl<T> extends AbstractClientExchangeHandler
         setCurrentRequest(request);
         setRoute(route);
 
-        this.localContext.setAttribute(HttpClientContext.HTTP_REQUEST, request);
-        this.localContext.setAttribute(HttpClientContext.HTTP_TARGET_HOST, target);
+        this.localContext.setAttribute(HttpCoreContext.HTTP_REQUEST, request);
+        this.localContext.setAttribute(HttpCoreContext.HTTP_TARGET_HOST, target);
         this.localContext.setAttribute(HttpClientContext.HTTP_ROUTE, route);
 
         this.httpProcessor.process(request, this.localContext);
@@ -171,11 +172,11 @@ class MinimalClientExchangeHandlerImpl<T> extends AbstractClientExchangeHandler
 
     @Override
     public void produceContent(
-            final ContentEncoder encoder, final IOControl ioctrl) throws IOException {
+            final ContentEncoder encoder, final IOControl ioControl) throws IOException {
         if (this.log.isDebugEnabled()) {
             this.log.debug("[exchange: " + getId() + "] produce content");
         }
-        this.requestProducer.produceContent(encoder, ioctrl);
+        this.requestProducer.produceContent(encoder, ioControl);
         if (encoder.isCompleted()) {
             this.requestProducer.resetRequest();
         }
@@ -195,7 +196,7 @@ class MinimalClientExchangeHandlerImpl<T> extends AbstractClientExchangeHandler
         if (this.log.isDebugEnabled()) {
             this.log.debug("[exchange: " + getId() + "] Response received " + response.getStatusLine());
         }
-        this.localContext.setAttribute(HttpClientContext.HTTP_RESPONSE, response);
+        this.localContext.setAttribute(HttpCoreContext.HTTP_RESPONSE, response);
         this.httpProcessor.process(response, this.localContext);
 
         setCurrentResponse(response);
@@ -205,11 +206,11 @@ class MinimalClientExchangeHandlerImpl<T> extends AbstractClientExchangeHandler
 
     @Override
     public void consumeContent(
-            final ContentDecoder decoder, final IOControl ioctrl) throws IOException {
+            final ContentDecoder decoder, final IOControl ioControl) throws IOException {
         if (this.log.isDebugEnabled()) {
             this.log.debug("[exchange: " + getId() + "] Consume content");
         }
-        this.responseConsumer.consumeContent(decoder, ioctrl);
+        this.responseConsumer.consumeContent(decoder, ioControl);
         if (!decoder.isCompleted() && this.responseConsumer.isDone()) {
             markConnectionNonReusable();
             try {
