@@ -37,6 +37,7 @@ import org.apache.http.HttpRequest;
 import org.apache.http.HttpResponse;
 import org.apache.http.client.methods.HttpDelete;
 import org.apache.http.client.methods.HttpGet;
+import org.apache.http.client.methods.HttpHead;
 import org.apache.http.client.methods.HttpOptions;
 import org.apache.http.client.methods.HttpPost;
 import org.apache.http.client.methods.HttpPut;
@@ -112,7 +113,7 @@ public final class HttpAsyncMethods {
      * @return asynchronous request generator
      */
     public static HttpAsyncRequestProducer createHead(final URI requestURI) {
-        return create(new HttpGet(requestURI));
+        return create(new HttpHead(requestURI));
     }
 
     /**
@@ -122,7 +123,7 @@ public final class HttpAsyncMethods {
      * @return asynchronous request generator
      */
     public static HttpAsyncRequestProducer createHead(final String requestURI) {
-        return create(new HttpGet(URI.create(requestURI)));
+        return create(new HttpHead(URI.create(requestURI)));
     }
 
     /**
