@@ -61,6 +61,7 @@ import org.junit.Before;
 import org.junit.Test;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
+import org.mockito.Matchers;
 import org.mockito.Mock;
 import org.mockito.Mockito;
 import org.mockito.MockitoAnnotations;
@@ -68,7 +69,7 @@ import org.mockito.MockitoAnnotations;
 public class TestPoolingHttpClientAsyncConnectionManager {
 
     @Mock
-    private ConnectingIOReactor ioreactor;
+    private ConnectingIOReactor ioReactor;
     @Mock
     private CPool pool;
     @Mock
@@ -90,7 +91,7 @@ public class TestPoolingHttpClientAsyncConnectionManager {
     @Mock
     private SessionRequest sessionRequest;
     @Mock
-    private IOSession iosession;
+    private IOSession ioSession;
 
     private Registry<SchemeIOSessionStrategy> layeringStrategyRegistry;
     private PoolingNHttpClientConnectionManager connman;
@@ -105,7 +106,7 @@ public class TestPoolingHttpClientAsyncConnectionManager {
             .register("https", sslStrategy)
             .build();
         connman = new PoolingNHttpClientConnectionManager(
-            ioreactor, pool, layeringStrategyRegistry);
+            ioReactor, pool, layeringStrategyRegistry);
     }
 
     @Test
@@ -131,11 +132,11 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         Assert.assertNotNull(future);
 
         Mockito.verify(pool).lease(
-                Mockito.same(route),
-                Mockito.eq("some state"),
-                Mockito.eq(1000L),
-                Mockito.eq(2000L),
-                Mockito.eq(TimeUnit.MILLISECONDS),
+                Matchers.same(route),
+                Matchers.eq("some state"),
+                Matchers.eq(1000L),
+                Matchers.eq(2000L),
+                Matchers.eq(TimeUnit.MILLISECONDS),
                 poolEntryCallbackCaptor.capture());
         final FutureCallback<CPoolEntry> callaback = poolEntryCallbackCaptor.getValue();
         final Log log = Mockito.mock(Log.class);
@@ -145,7 +146,7 @@ public class TestPoolingHttpClientAsyncConnectionManager {
 
         Assert.assertTrue(future.isDone());
         final NHttpClientConnection managedConn = future.get();
-        Mockito.verify(connCallback).completed(Mockito.<NHttpClientConnection>any());
+        Mockito.verify(connCallback).completed(Matchers.<NHttpClientConnection>any());
 
         Mockito.when(conn.isOpen()).thenReturn(Boolean.TRUE);
         connman.releaseConnection(managedConn, "new state", 5, TimeUnit.SECONDS);
@@ -167,11 +168,11 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         Assert.assertNotNull(future);
 
         Mockito.verify(pool).lease(
-                Mockito.same(route),
-                Mockito.eq("some state"),
-                Mockito.eq(1000L),
-                Mockito.eq(2000L),
-                Mockito.eq(TimeUnit.MILLISECONDS),
+                Matchers.same(route),
+                Matchers.eq("some state"),
+                Matchers.eq(1000L),
+                Matchers.eq(2000L),
+                Matchers.eq(TimeUnit.MILLISECONDS),
                 poolEntryCallbackCaptor.capture());
         final FutureCallback<CPoolEntry> callaback = poolEntryCallbackCaptor.getValue();
         final Log log = Mockito.mock(Log.class);
@@ -180,7 +181,7 @@ public class TestPoolingHttpClientAsyncConnectionManager {
 
         Assert.assertTrue(future.isDone());
         final NHttpClientConnection managedConn = future.get();
-        Mockito.verify(connCallback).completed(Mockito.<NHttpClientConnection>any());
+        Mockito.verify(connCallback).completed(Matchers.<NHttpClientConnection>any());
 
         Mockito.when(conn.isOpen()).thenReturn(Boolean.TRUE);
         connman.releaseConnection(managedConn, "new state", 5, TimeUnit.SECONDS);
@@ -198,11 +199,11 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         future.cancel(true);
 
         Mockito.verify(pool).lease(
-                Mockito.same(route),
-                Mockito.eq("some state"),
-                Mockito.eq(1000L),
-                Mockito.eq(2000L),
-                Mockito.eq(TimeUnit.MILLISECONDS),
+                Matchers.same(route),
+                Matchers.eq("some state"),
+                Matchers.eq(1000L),
+                Matchers.eq(2000L),
+                Matchers.eq(TimeUnit.MILLISECONDS),
                 poolEntryCallbackCaptor.capture());
         final FutureCallback<CPoolEntry> callaback = poolEntryCallbackCaptor.getValue();
         final Log log = Mockito.mock(Log.class);
@@ -222,11 +223,11 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         Assert.assertNotNull(future);
 
         Mockito.verify(pool).lease(
-                Mockito.same(route),
-                Mockito.eq("some state"),
-                Mockito.eq(1000L),
-                Mockito.eq(2000L),
-                Mockito.eq(TimeUnit.MILLISECONDS),
+                Matchers.same(route),
+                Matchers.eq("some state"),
+                Matchers.eq(1000L),
+                Matchers.eq(2000L),
+                Matchers.eq(TimeUnit.MILLISECONDS),
                 poolEntryCallbackCaptor.capture());
         final FutureCallback<CPoolEntry> callaback = poolEntryCallbackCaptor.getValue();
         callaback.failed(new Exception());
@@ -244,11 +245,11 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         Assert.assertNotNull(future);
 
         Mockito.verify(pool).lease(
-                Mockito.same(route),
-                Mockito.eq("some state"),
-                Mockito.eq(1000L),
-                Mockito.eq(2000L),
-                Mockito.eq(TimeUnit.MILLISECONDS),
+                Matchers.same(route),
+                Matchers.eq("some state"),
+                Matchers.eq(1000L),
+                Matchers.eq(2000L),
+                Matchers.eq(TimeUnit.MILLISECONDS),
                 poolEntryCallbackCaptor.capture());
         final FutureCallback<CPoolEntry> callaback = poolEntryCallbackCaptor.getValue();
         callaback.cancelled();
@@ -268,13 +269,13 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         final CPoolEntry poolentry = new CPoolEntry(log, "some-id", route, conn, -1, TimeUnit.MILLISECONDS);
         final NHttpClientConnection managedConn = CPoolProxy.newProxy(poolentry);
 
-        Mockito.when(conn.getIOSession()).thenReturn(iosession);
-        Mockito.when(sslStrategy.upgrade(target, iosession)).thenReturn(iosession);
+        Mockito.when(conn.getIOSession()).thenReturn(ioSession);
+        Mockito.when(sslStrategy.upgrade(target, ioSession)).thenReturn(ioSession);
 
         connman.startRoute(managedConn, route, context);
 
-        Mockito.verify(noopStrategy, Mockito.never()).upgrade(target, iosession);
-        Mockito.verify(conn, Mockito.never()).bind(iosession);
+        Mockito.verify(noopStrategy, Mockito.never()).upgrade(target, ioSession);
+        Mockito.verify(conn, Mockito.never()).bind(ioSession);
 
         Assert.assertFalse(connman.isRouteComplete(managedConn));
     }
@@ -290,13 +291,13 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         poolentry.markRouteComplete();
         final NHttpClientConnection managedConn = CPoolProxy.newProxy(poolentry);
 
-        Mockito.when(conn.getIOSession()).thenReturn(iosession);
-        Mockito.when(sslStrategy.upgrade(target, iosession)).thenReturn(iosession);
+        Mockito.when(conn.getIOSession()).thenReturn(ioSession);
+        Mockito.when(sslStrategy.upgrade(target, ioSession)).thenReturn(ioSession);
 
         connman.startRoute(managedConn, route, context);
 
-        Mockito.verify(sslStrategy).upgrade(target, iosession);
-        Mockito.verify(conn).bind(iosession);
+        Mockito.verify(sslStrategy).upgrade(target, ioSession);
+        Mockito.verify(conn).bind(ioSession);
     }
 
     @Test
@@ -314,13 +315,13 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         final CPoolEntry poolentry = new CPoolEntry(log, "some-id", route, conn, -1, TimeUnit.MILLISECONDS);
         final NHttpClientConnection managedConn = CPoolProxy.newProxy(poolentry);
 
-        Mockito.when(conn.getIOSession()).thenReturn(iosession);
-        Mockito.when(sslStrategy.upgrade(target, iosession)).thenReturn(iosession);
+        Mockito.when(conn.getIOSession()).thenReturn(ioSession);
+        Mockito.when(sslStrategy.upgrade(target, ioSession)).thenReturn(ioSession);
 
         connman.startRoute(managedConn, route, context);
 
-        Mockito.verify(noopStrategy, Mockito.never()).upgrade(target, iosession);
-        Mockito.verify(conn, Mockito.never()).bind(iosession);
+        Mockito.verify(noopStrategy, Mockito.never()).upgrade(target, ioSession);
+        Mockito.verify(conn, Mockito.never()).bind(ioSession);
 
         Assert.assertFalse(connman.isRouteComplete(managedConn));
     }
@@ -336,8 +337,8 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         poolentry.markRouteComplete();
         final NHttpClientConnection managedConn = CPoolProxy.newProxy(poolentry);
 
-        Mockito.when(conn.getIOSession()).thenReturn(iosession);
-        Mockito.when(sslStrategy.upgrade(target, iosession)).thenReturn(iosession);
+        Mockito.when(conn.getIOSession()).thenReturn(ioSession);
+        Mockito.when(sslStrategy.upgrade(target, ioSession)).thenReturn(ioSession);
 
         connman.startRoute(managedConn, route, context);
     }
@@ -353,13 +354,13 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         poolentry.markRouteComplete();
         final NHttpClientConnection managedConn = CPoolProxy.newProxy(poolentry);
 
-        Mockito.when(conn.getIOSession()).thenReturn(iosession);
-        Mockito.when(sslStrategy.upgrade(target, iosession)).thenReturn(iosession);
+        Mockito.when(conn.getIOSession()).thenReturn(ioSession);
+        Mockito.when(sslStrategy.upgrade(target, ioSession)).thenReturn(ioSession);
 
         connman.upgrade(managedConn, route, context);
 
-        Mockito.verify(sslStrategy).upgrade(target, iosession);
-        Mockito.verify(conn).bind(iosession);
+        Mockito.verify(sslStrategy).upgrade(target, ioSession);
+        Mockito.verify(conn).bind(ioSession);
     }
 
     @Test(expected=UnsupportedSchemeException.class)
@@ -373,8 +374,8 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         poolentry.markRouteComplete();
         final NHttpClientConnection managedConn = CPoolProxy.newProxy(poolentry);
 
-        Mockito.when(conn.getIOSession()).thenReturn(iosession);
-        Mockito.when(sslStrategy.upgrade(target, iosession)).thenReturn(iosession);
+        Mockito.when(conn.getIOSession()).thenReturn(ioSession);
+        Mockito.when(sslStrategy.upgrade(target, ioSession)).thenReturn(ioSession);
 
         connman.upgrade(managedConn, route, context);
     }
@@ -390,8 +391,8 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         poolentry.markRouteComplete();
         final NHttpClientConnection managedConn = CPoolProxy.newProxy(poolentry);
 
-        Mockito.when(conn.getIOSession()).thenReturn(iosession);
-        Mockito.when(sslStrategy.upgrade(target, iosession)).thenReturn(iosession);
+        Mockito.when(conn.getIOSession()).thenReturn(ioSession);
+        Mockito.when(sslStrategy.upgrade(target, ioSession)).thenReturn(ioSession);
 
         connman.upgrade(managedConn, route, context);
     }
@@ -407,8 +408,8 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         poolentry.markRouteComplete();
         final NHttpClientConnection managedConn = CPoolProxy.newProxy(poolentry);
 
-        Mockito.when(conn.getIOSession()).thenReturn(iosession);
-        Mockito.when(sslStrategy.upgrade(target, iosession)).thenReturn(iosession);
+        Mockito.when(conn.getIOSession()).thenReturn(ioSession);
+        Mockito.when(sslStrategy.upgrade(target, ioSession)).thenReturn(ioSession);
 
         connman.startRoute(managedConn, route, context);
         connman.routeComplete(managedConn, route, context);
@@ -457,11 +458,11 @@ public class TestPoolingHttpClientAsyncConnectionManager {
             configData, connFactory);
 
         final HttpRoute route = new HttpRoute(new HttpHost("somehost", 80));
-        internalConnFactory.create(route, iosession);
+        internalConnFactory.create(route, ioSession);
 
-        Mockito.verify(sslStrategy, Mockito.never()).upgrade(Mockito.eq(new HttpHost("somehost", 80)),
-                Mockito.<IOSession>any());
-        Mockito.verify(connFactory).create(Mockito.same(iosession), Mockito.<ConnectionConfig>any());
+        Mockito.verify(sslStrategy, Mockito.never()).upgrade(Matchers.eq(new HttpHost("somehost", 80)),
+                Matchers.<IOSession>any());
+        Mockito.verify(connFactory).create(Matchers.same(ioSession), Matchers.<ConnectionConfig>any());
     }
 
     @Test
@@ -477,9 +478,9 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         final ConnectionConfig config = ConnectionConfig.custom().build();
         configData.setConnectionConfig(proxy, config);
 
-        internalConnFactory.create(route, iosession);
+        internalConnFactory.create(route, ioSession);
 
-        Mockito.verify(connFactory).create(iosession, config);
+        Mockito.verify(connFactory).create(ioSession, config);
     }
 
     @Test
@@ -494,9 +495,9 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         final ConnectionConfig config = ConnectionConfig.custom().build();
         configData.setConnectionConfig(target, config);
 
-        internalConnFactory.create(route, iosession);
+        internalConnFactory.create(route, ioSession);
 
-        Mockito.verify(connFactory).create(iosession, config);
+        Mockito.verify(connFactory).create(ioSession, config);
     }
 
     @Test
@@ -511,9 +512,9 @@ public class TestPoolingHttpClientAsyncConnectionManager {
         final ConnectionConfig config = ConnectionConfig.custom().build();
         configData.setDefaultConnectionConfig(config);
 
-        internalConnFactory.create(route, iosession);
+        internalConnFactory.create(route, ioSession);
 
-        Mockito.verify(connFactory).create(iosession, config);
+        Mockito.verify(connFactory).create(ioSession, config);
     }
 
     @Test
@@ -527,9 +528,9 @@ public class TestPoolingHttpClientAsyncConnectionManager {
 
         configData.setDefaultConnectionConfig(null);
 
-        internalConnFactory.create(route, iosession);
+        internalConnFactory.create(route, ioSession);
 
-        Mockito.verify(connFactory).create(iosession, ConnectionConfig.DEFAULT);
+        Mockito.verify(connFactory).create(ioSession, ConnectionConfig.DEFAULT);
     }
 
     @Test
